@@ -4,23 +4,24 @@ capture_first_vec <- structure(function # Capture first match in each character
 ### all matches in one multi-line text file or string use
 ### capture_all_str. For the first match in every row of a data.frame,
 ### using a different regex for each column, use capture_first_df. For
+### reading regularly named files, use capture_first_glob. For
 ### matching column names in a wide data frame and then
 ### melting/reshaping those columns to a taller/longer data frame, see
 ### capture_melt_single and capture_melt_multiple. To simplify the
 ### definition of the regex you can use field, quantifier, and
 ### alternatives.
 (...,
-### subject, name1=pattern1, fun1, etc. The first argument
-### must be a character vector of length>0 (subject strings to parse
-### with a regex). Arguments after the first specify the
-### regex/conversion and must be character/function/list. All
-### character strings are pasted together to obtain the final regex
-### used for matching. Each string with a named argument in R becomes
-### a capture group in the regex, and the name is used for the
-### corresponding column of the output data table. Each named pattern
-### may be followed by at most one function which is used to convert
-### the values captured by that pattern. Lists are parsed recursively
-### for convenience.
+### subject, name1=pattern1, fun1, etc. The first argument must be a
+### character vector of length>0 (subject strings to parse with a
+### regex). Arguments after the first specify the regex/conversion and
+### must be string/list/function. All character strings are pasted
+### together to obtain the final regex used for matching. Each
+### string/list with a named argument in R becomes a capture group in
+### the regex, and the name is used for the corresponding column of
+### the output data table. Each function must be un-named, and is used
+### to convert the previous capture group. Each un-named list becomes
+### a non-capturing group. Elements in each list are parsed
+### recursively using these rules.
   nomatch.error=getOption("nc.nomatch.error", TRUE),
 ### if TRUE (default), stop with an error if any subject does not
 ### match; otherwise subjects that do not match are reported as
@@ -34,15 +35,9 @@ capture_first_vec <- structure(function # Capture first match in each character
   ##alias<< nc
   stop_for_na <- function(no.match){
     if(isTRUE(nomatch.error) && any(no.match)){
-      i <- which(no.match)
-      stop(
-        "subject",
-        ifelse(length(i)==1, "", "s"),
-        " ",
-        paste(i, collapse=","),
-        " did not match regex below; ",
-        "to output missing rows use nomatch.error=FALSE\n",
-        L[["pattern"]])
+      no.match.i <- which(no.match)
+      stop(domain=NA, gettextf("subject(s) %s (%d total) did not match regex below; to output missing rows use nomatch.error=FALSE
+%s", collapse_some(no.match.i), length(no.match.i), L[["pattern"]]))
     }
   }
   m <- if(engine=="PCRE"){
@@ -61,7 +56,7 @@ capture_first_vec <- structure(function # Capture first match in each character
     match.fun <- if(engine=="ICU"){
       stringi::stri_match_first_regex
     }else{
-      re2r::re2_match
+      re2::re2_match
     }
     match.mat <- try_or_stop_print_pattern({
       match.fun(subject.vec, L[["pattern"]])
@@ -69,11 +64,7 @@ capture_first_vec <- structure(function # Capture first match in each character
     only_captures(match.mat, stop_for_na)
   }
   if(length(L[["fun.list"]]) < ncol(m)){
-    stop(
-      "regex contains more groups than names; ",
-      "please remove literal groups (parentheses) ",
-      "from the regex pattern, ",
-      "and use named arguments in R code instead")
+    stop(domain=NA, gettext("regex contains more groups than names; please remove literal groups (parentheses) from the regex pattern, and use named arguments in R code instead"))
   }
   apply_type_funs(m, L[["fun.list"]])
 ### data.table with one row for each subject, and one column for each
